@@ -34,7 +34,8 @@
 #'     tokens_remove("b", padding = TRUE)
 #' toks
 #' dfm(toks)
-#' dfm(toks, remove = "") # remove "pads"
+#' dfm(toks) %>%
+#'  dfm_remove(pattern = "") # remove "pads"
 #'
 #' # preserving case
 #' dfm(toks, tolower = FALSE)
@@ -379,11 +380,11 @@ dfm.dfm <- function(x,
 make_null_dfm <- function(feature = NULL, document = NULL) {
     if (is.null(feature)) feature <- character()
     if (is.null(document)) document <- character()
-    temp <- as(sparseMatrix(
+    temp <- as(as(as(sparseMatrix(
         i = NULL,
         j = NULL,
         dims = c(length(document), length(feature))
-    ), "dgCMatrix")
+    ), "CsparseMatrix"), "generalMatrix"), "dMatrix")
 
     build_dfm(temp, feature,
               docvars = make_docvars(length(document), document))
